@@ -714,7 +714,8 @@ class main:
             os.chmod (path, stat.S_IEXEC | stat.S_IREAD)
 
             # unset POSIXLY_CORRECT if manually set, bug 612459
-            if self.manual_poscorrect: os.unsetenv ('POSIXLY_CORRECT')
+            if self.manual_poscorrect:
+              del os.environ['POSIXLY_CORRECT']
 
             # get terminal and exec params
             terminal = None
@@ -740,7 +741,8 @@ class main:
             tex = terminal.strip () + ' ' + terminalparam.strip () + ' ' + execute
             subprocess.Popen(tex, cwd = self.user_home_dir, shell=True)
 
-            if self.manual_poscorrect: os.putenv ('POSIXLY_CORRECT', 'enabled')
+            if self.manual_poscorrect:
+              os.environ['POSIXLY_CORRECT'] = 'enabled'
 
 
         except Exception, ex:
@@ -756,7 +758,7 @@ class main:
         dlg.set_title (_("About Gnome Schedule"))
         dlg.set_name (_("Gnome Schedule"))
         dlg.set_version (config.getVersion())
-        dlg.set_copyright (_("Copyright (c) %(year)s %(name)s.") % ({ 'year' : "2004-2013", 'name' : "Gaute Hope"}))
+        dlg.set_copyright (_("Copyright (c) %(year)s %(name)s.") % ({ 'year' : "2004-2015", 'name' : "Gaute Hope"}))
         #dlg.set_comments ()
         #dlg.set_license ()
         dlg.set_website ("http://gnome-schedule.sourceforge.net")
